Skip site navigation (1)Skip section navigation (2)
Date:      Sat, 14 Mar 2026 09:38:25 +0000
From:      Pouria Mousavizadeh Tehrani <pouria@FreeBSD.org>
To:        src-committers@FreeBSD.org, dev-commits-src-all@FreeBSD.org, dev-commits-src-main@FreeBSD.org
Subject:   git: f91464171d61 - main - acpi_system76: Improve sysctl names
Message-ID:  <69b52c91.18eab.42be8b26@gitrepo.freebsd.org>

index | next in thread | raw e-mail

The branch main has been updated by pouria:

URL: https://cgit.FreeBSD.org/src/commit/?id=f91464171d615b7e7720ac9ed67e2e86392d1b41

commit f91464171d615b7e7720ac9ed67e2e86392d1b41
Author:     Pouria Mousavizadeh Tehrani <pouria@FreeBSD.org>
AuthorDate: 2026-03-13 19:23:03 +0000
Commit:     Pouria Mousavizadeh Tehrani <pouria@FreeBSD.org>
CommitDate: 2026-03-14 09:33:10 +0000

    acpi_system76: Improve sysctl names
    
    * Improve sysctl descriptions.
    * Rename battery charging-threshold sysctl for clarity.
    * Fix mis-spelled words.
    * Style: sort headers.
    
    Reported by: olce, jhb
    Reviewed by: olce
    Differential Revision: https://reviews.freebsd.org/D55848
---
 sys/dev/acpi_support/acpi_system76.c | 21 +++++++++++----------
 1 file changed, 11 insertions(+), 10 deletions(-)

diff --git a/sys/dev/acpi_support/acpi_system76.c b/sys/dev/acpi_support/acpi_system76.c
index a4ac848a0fec..1ba287ccb85d 100644
--- a/sys/dev/acpi_support/acpi_system76.c
+++ b/sys/dev/acpi_support/acpi_system76.c
@@ -27,18 +27,19 @@
  */
 
 #include "opt_acpi.h"
+
 #include <sys/param.h>
-#include <sys/kernel.h>
 #include <sys/bus.h>
+#include <sys/kernel.h>
 #include <sys/module.h>
+#include <sys/sysctl.h>
 
 #include <contrib/dev/acpica/include/acpi.h>
 #include <contrib/dev/acpica/include/accommon.h>
 
 #include <dev/acpica/acpivar.h>
-#include <sys/sysctl.h>
-
 #include <dev/backlight/backlight.h>
+
 #include "backlight_if.h"
 
 #define _COMPONENT ACPI_OEM
@@ -91,8 +92,8 @@ static int	acpi_system76_backlight_get_info(device_t dev,
 enum {
 	S76_CTRL_KBB	= 1,	/* Keyboard Brightness */
 	S76_CTRL_KBC	= 2,	/* Keyboard Color */
-	S76_CTRL_BCTL	= 3,	/* Battary Charging Start Thresholds */
-	S76_CTRL_BCTH	= 4,	/* Battary Charging End Thresholds */
+	S76_CTRL_BCTL	= 3,	/* Battery Charging Start Thresholds */
+	S76_CTRL_BCTH	= 4,	/* Battery Charging End Thresholds */
 };
 #define	S76_CTRL_MAX	5
 
@@ -125,16 +126,16 @@ static const struct s76_ctrl_table s76_sysctl_table[] = {
 		.desc = "Keyboard Color",
 	},
 	[S76_CTRL_BCTL] = {
-		.name = "battary_thresholds_low",
+		.name = "battery_charge_min",
 		.get_method = S76_CTRL_GBCT,
 		.set_method = S76_CTRL_SBCT,
-		.desc = "Battary charging start thresholds",
+		.desc = "Start charging the battery when this threshold is reached (percentage)",
 	},
 	[S76_CTRL_BCTH] = {
-		.name = "battary_thresholds_high",
+		.name = "battery_charge_max",
 		.get_method = S76_CTRL_GBCT,
 		.set_method = S76_CTRL_SBCT,
-		.desc = "Battary charging end thresholds",
+		.desc = "Stop charging the battery when this threshold is reached (percentage)",
 	},
 };
 
@@ -376,7 +377,7 @@ acpi_system76_sysctl_handler(SYSCTL_HANDLER_ARGS)
 
 	if (req->newptr == NULL) {
 		/*
 		 * ACPI will not notify us if battary thresholds changes
 		 * outside this module. Therefore, always fetch those values.
 		 */
 		if (method != S76_CTRL_BCTL && method != S76_CTRL_BCTH)
@@ -376,7 +377,7 @@ acpi_system76_sysctl_handler(SYSCTL_HANDLER_ARGS)
 	if (req->newptr == NULL) {
 		/*
-		 * ACPI will not notify us if battary thresholds changes
+		 * ACPI will not notify us if battery thresholds changes
 		 * outside this module. Therefore, always fetch those values.
 		 */


home | help

Want to link to this message? Use this
URL: <https://mail-archive.FreeBSD.org/cgi/mid.cgi?69b52c91.18eab.42be8b26>